import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::ApiGateway::BasePathMappingV2
 */
export declare class BasePathMappingV2 extends pulumi.CustomResource {
    /**
     * Get an existing BasePathMappingV2 resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BasePathMappingV2;
    /**
     * Returns true if the given object is an instance of BasePathMappingV2.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BasePathMappingV2;
    /**
     * The base path name that callers of the API must provide in the URL after the domain name.
     */
    readonly basePath: pulumi.Output<string | undefined>;
    /**
     * Amazon Resource Name (ARN) of the resource.
     */
    readonly basePathMappingArn: pulumi.Output<string>;
    /**
     * The Arn of an AWS::ApiGateway::DomainNameV2 resource.
     */
    readonly domainNameArn: pulumi.Output<string>;
    /**
     * The ID of the API.
     */
    readonly restApiId: pulumi.Output<string>;
    /**
     * The name of the API's stage.
     */
    readonly stage: pulumi.Output<string | undefined>;
    /**
     * Create a BasePathMappingV2 resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BasePathMappingV2Args, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BasePathMappingV2 resource.
 */
export interface BasePathMappingV2Args {
    /**
     * The base path name that callers of the API must provide in the URL after the domain name.
     */
    basePath?: pulumi.Input<string>;
    /**
     * The Arn of an AWS::ApiGateway::DomainNameV2 resource.
     */
    domainNameArn: pulumi.Input<string>;
    /**
     * The ID of the API.
     */
    restApiId: pulumi.Input<string>;
    /**
     * The name of the API's stage.
     */
    stage?: pulumi.Input<string>;
}
