import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The ``AWS::ApiGateway::UsagePlanKey`` resource associates an API key with a usage plan. This association determines which users the usage plan is applied to.
 */
export declare class UsagePlanKey extends pulumi.CustomResource {
    /**
     * Get an existing UsagePlanKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): UsagePlanKey;
    /**
     * Returns true if the given object is an instance of UsagePlanKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UsagePlanKey;
    /**
     * The ID for the usage plan key. For example: `abc123` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The Id of the UsagePlanKey resource.
     */
    readonly keyId: pulumi.Output<string>;
    /**
     * The type of a UsagePlanKey resource for a plan customer.
     */
    readonly keyType: pulumi.Output<enums.apigateway.UsagePlanKeyKeyType>;
    /**
     * The Id of the UsagePlan resource representing the usage plan containing the UsagePlanKey resource representing a plan customer.
     */
    readonly usagePlanId: pulumi.Output<string>;
    /**
     * Create a UsagePlanKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UsagePlanKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a UsagePlanKey resource.
 */
export interface UsagePlanKeyArgs {
    /**
     * The Id of the UsagePlanKey resource.
     */
    keyId: pulumi.Input<string>;
    /**
     * The type of a UsagePlanKey resource for a plan customer.
     */
    keyType: pulumi.Input<enums.apigateway.UsagePlanKeyKeyType>;
    /**
     * The Id of the UsagePlan resource representing the usage plan containing the UsagePlanKey resource representing a plan customer.
     */
    usagePlanId: pulumi.Input<string>;
}
