import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::AppRunner::VpcIngressConnection resource is an App Runner resource that specifies an App Runner VpcIngressConnection.
 */
export declare class VpcIngressConnection extends pulumi.CustomResource {
    /**
     * Get an existing VpcIngressConnection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcIngressConnection;
    /**
     * Returns true if the given object is an instance of VpcIngressConnection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcIngressConnection;
    /**
     * The Domain name associated with the VPC Ingress Connection.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * Specifications for the customer’s Amazon VPC and the related AWS PrivateLink VPC endpoint that are used to create the VPC Ingress Connection resource.
     */
    readonly ingressVpcConfiguration: pulumi.Output<outputs.apprunner.VpcIngressConnectionIngressVpcConfiguration>;
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    readonly serviceArn: pulumi.Output<string>;
    /**
     * The current status of the VpcIngressConnection.
     */
    readonly status: pulumi.Output<enums.apprunner.VpcIngressConnectionStatus>;
    /**
     * An optional list of metadata items that you can associate with the VPC Ingress Connection resource. A tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the VpcIngressConnection.
     */
    readonly vpcIngressConnectionArn: pulumi.Output<string>;
    /**
     * The customer-provided Vpc Ingress Connection name.
     */
    readonly vpcIngressConnectionName: pulumi.Output<string | undefined>;
    /**
     * Create a VpcIngressConnection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcIngressConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcIngressConnection resource.
 */
export interface VpcIngressConnectionArgs {
    /**
     * Specifications for the customer’s Amazon VPC and the related AWS PrivateLink VPC endpoint that are used to create the VPC Ingress Connection resource.
     */
    ingressVpcConfiguration: pulumi.Input<inputs.apprunner.VpcIngressConnectionIngressVpcConfigurationArgs>;
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    serviceArn: pulumi.Input<string>;
    /**
     * An optional list of metadata items that you can associate with the VPC Ingress Connection resource. A tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
    /**
     * The customer-provided Vpc Ingress Connection name.
     */
    vpcIngressConnectionName?: pulumi.Input<string>;
}
