import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Backup::RestoreTestingPlan Resource Type
 */
export declare class RestoreTestingPlan extends pulumi.CustomResource {
    /**
     * Get an existing RestoreTestingPlan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RestoreTestingPlan;
    /**
     * Returns true if the given object is an instance of RestoreTestingPlan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RestoreTestingPlan;
    /**
     * The specified criteria to assign a set of resources, such as recovery point types or backup vaults.
     */
    readonly recoveryPointSelection: pulumi.Output<outputs.backup.RestoreTestingPlanRestoreTestingRecoveryPointSelection>;
    /**
     * An Amazon Resource Name (ARN) that uniquely identifies a restore testing plan.
     */
    readonly restoreTestingPlanArn: pulumi.Output<string>;
    /**
     * The RestoreTestingPlanName is a unique string that is the name of the restore testing plan. This cannot be changed after creation, and it must consist of only alphanumeric characters and underscores.
     */
    readonly restoreTestingPlanName: pulumi.Output<string>;
    /**
     * A CRON expression in specified timezone when a restore testing plan is executed. When no CRON expression is provided, AWS Backup will use the default expression `cron(0 5 ? * * *)` .
     */
    readonly scheduleExpression: pulumi.Output<string>;
    /**
     * Optional. This is the timezone in which the schedule expression is set. By default, ScheduleExpressions are in UTC. You can modify this to a specified timezone.
     */
    readonly scheduleExpressionTimezone: pulumi.Output<string | undefined>;
    /**
     * Defaults to 24 hours.
     *
     * A value in hours after a restore test is scheduled before a job will be canceled if it doesn't start successfully. This value is optional. If this value is included, this parameter has a maximum value of 168 hours (one week).
     */
    readonly startWindowHours: pulumi.Output<number | undefined>;
    /**
     * Optional tags to include. A tag is a key-value pair you can use to manage, filter, and search for your resources. Allowed characters include UTF-8 letters,numbers, spaces, and the following characters: `+ - = . _ : /.`
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a RestoreTestingPlan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RestoreTestingPlanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RestoreTestingPlan resource.
 */
export interface RestoreTestingPlanArgs {
    /**
     * The specified criteria to assign a set of resources, such as recovery point types or backup vaults.
     */
    recoveryPointSelection: pulumi.Input<inputs.backup.RestoreTestingPlanRestoreTestingRecoveryPointSelectionArgs>;
    /**
     * The RestoreTestingPlanName is a unique string that is the name of the restore testing plan. This cannot be changed after creation, and it must consist of only alphanumeric characters and underscores.
     */
    restoreTestingPlanName?: pulumi.Input<string>;
    /**
     * A CRON expression in specified timezone when a restore testing plan is executed. When no CRON expression is provided, AWS Backup will use the default expression `cron(0 5 ? * * *)` .
     */
    scheduleExpression: pulumi.Input<string>;
    /**
     * Optional. This is the timezone in which the schedule expression is set. By default, ScheduleExpressions are in UTC. You can modify this to a specified timezone.
     */
    scheduleExpressionTimezone?: pulumi.Input<string>;
    /**
     * Defaults to 24 hours.
     *
     * A value in hours after a restore test is scheduled before a job will be canceled if it doesn't start successfully. This value is optional. If this value is included, this parameter has a maximum value of 168 hours (one week).
     */
    startWindowHours?: pulumi.Input<number>;
    /**
     * Optional tags to include. A tag is a key-value pair you can use to manage, filter, and search for your resources. Allowed characters include UTF-8 letters,numbers, spaces, and the following characters: `+ - = . _ : /.`
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
