import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An origin request policy.
 *  When it's attached to a cache behavior, the origin request policy determines the values that CloudFront includes in requests that it sends to the origin. Each request that CloudFront sends to the origin includes the following:
 *   +  The request body and the URL path (without the domain name) from the viewer request.
 *   +  The headers that CloudFront automatically includes in every origin request, including ``Host``, ``User-Agent``, and ``X-Amz-Cf-Id``.
 *   +  All HTTP headers, cookies, and URL query strings that are specified in the cache policy or the origin request policy. These can include items from the viewer request and, in the case of headers, additional ones that are added by CloudFront.
 *
 *  CloudFront sends a request when it can't find an object in its cache that matches the request. If you want to send values to the origin and also include them in the cache key, use ``CachePolicy``.
 */
export declare class OriginRequestPolicy extends pulumi.CustomResource {
    /**
     * Get an existing OriginRequestPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): OriginRequestPolicy;
    /**
     * Returns true if the given object is an instance of OriginRequestPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OriginRequestPolicy;
    /**
     * The unique identifier for the origin request policy. For example: `befd7079-9bbc-4ebf-8ade-498a3694176c` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The date and time when the origin request policy was last modified.
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * The origin request policy configuration.
     */
    readonly originRequestPolicyConfig: pulumi.Output<outputs.cloudfront.OriginRequestPolicyConfig>;
    /**
     * Create a OriginRequestPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OriginRequestPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a OriginRequestPolicy resource.
 */
export interface OriginRequestPolicyArgs {
    /**
     * The origin request policy configuration.
     */
    originRequestPolicyConfig: pulumi.Input<inputs.cloudfront.OriginRequestPolicyConfigArgs>;
}
