import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Schema for AWS::CodeStarConnections::RepositoryLink resource which is used to aggregate repository metadata relevant to synchronizing source provider content to AWS Resources.
 */
export declare function getRepositoryLink(args: GetRepositoryLinkArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryLinkResult>;
export interface GetRepositoryLinkArgs {
    /**
     * A unique Amazon Resource Name (ARN) to designate the repository link.
     */
    repositoryLinkArn: string;
}
export interface GetRepositoryLinkResult {
    /**
     * The Amazon Resource Name (ARN) of the CodeStarConnection. The ARN is used as the connection reference when the connection is shared between AWS services.
     */
    readonly connectionArn?: string;
    /**
     * The ARN of the KMS key that the customer can optionally specify to use to encrypt RepositoryLink properties. If not specified, a default key will be used.
     */
    readonly encryptionKeyArn?: string;
    /**
     * The name of the external provider where your third-party code repository is configured.
     */
    readonly providerType?: enums.codestarconnections.RepositoryLinkProviderType;
    /**
     * A unique Amazon Resource Name (ARN) to designate the repository link.
     */
    readonly repositoryLinkArn?: string;
    /**
     * A UUID that uniquely identifies the RepositoryLink.
     */
    readonly repositoryLinkId?: string;
    /**
     * Specifies the tags applied to a RepositoryLink.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Schema for AWS::CodeStarConnections::RepositoryLink resource which is used to aggregate repository metadata relevant to synchronizing source provider content to AWS Resources.
 */
export declare function getRepositoryLinkOutput(args: GetRepositoryLinkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryLinkResult>;
export interface GetRepositoryLinkOutputArgs {
    /**
     * A unique Amazon Resource Name (ARN) to designate the repository link.
     */
    repositoryLinkArn: pulumi.Input<string>;
}
