import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Cognito::UserPoolDomain
 */
export declare function getUserPoolDomain(args: GetUserPoolDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetUserPoolDomainResult>;
export interface GetUserPoolDomainArgs {
    /**
     * The name of the domain that you want to update. For custom domains, this is the fully-qualified domain name, for example `auth.example.com` . For prefix domains, this is the prefix alone, such as `myprefix` .
     */
    domain: string;
    /**
     * The ID of the user pool that is associated with the domain you're updating.
     */
    userPoolId: string;
}
export interface GetUserPoolDomainResult {
    /**
     * The Amazon CloudFront endpoint that you use as the target of the alias that you set up with your Domain Name Service (DNS) provider.
     */
    readonly cloudFrontDistribution?: string;
    /**
     * The configuration for a custom domain that hosts the sign-up and sign-in pages for your application. Use this object to specify an SSL certificate that is managed by ACM.
     *
     * When you create a custom domain, the passkey RP ID defaults to the custom domain. If you had a prefix domain active, this will cause passkey integration for your prefix domain to stop working due to a mismatch in RP ID. To keep the prefix domain passkey integration working, you can explicitly set RP ID to the prefix domain.
     */
    readonly customDomainConfig?: outputs.cognito.UserPoolDomainCustomDomainConfigType;
}
/**
 * Resource Type definition for AWS::Cognito::UserPoolDomain
 */
export declare function getUserPoolDomainOutput(args: GetUserPoolDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserPoolDomainResult>;
export interface GetUserPoolDomainOutputArgs {
    /**
     * The name of the domain that you want to update. For custom domains, this is the fully-qualified domain name, for example `auth.example.com` . For prefix domains, this is the prefix alone, such as `myprefix` .
     */
    domain: pulumi.Input<string>;
    /**
     * The ID of the user pool that is associated with the domain you're updating.
     */
    userPoolId: pulumi.Input<string>;
}
