import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::HoursOfOperation
 */
export declare function getHoursOfOperation(args: GetHoursOfOperationArgs, opts?: pulumi.InvokeOptions): Promise<GetHoursOfOperationResult>;
export interface GetHoursOfOperationArgs {
    /**
     * The Amazon Resource Name (ARN) for the hours of operation.
     */
    hoursOfOperationArn: string;
}
export interface GetHoursOfOperationResult {
    /**
     * Configuration information for the hours of operation: day, start time, and end time.
     */
    readonly config?: outputs.connect.HoursOfOperationConfig[];
    /**
     * The description of the hours of operation.
     */
    readonly description?: string;
    /**
     * The Amazon Resource Name (ARN) for the hours of operation.
     */
    readonly hoursOfOperationArn?: string;
    /**
     * One or more hours of operation overrides assigned to an hour of operation.
     */
    readonly hoursOfOperationOverrides?: outputs.connect.HoursOfOperationOverride[];
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn?: string;
    /**
     * The name of the hours of operation.
     */
    readonly name?: string;
    /**
     * One or more tags.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The time zone of the hours of operation.
     */
    readonly timeZone?: string;
}
/**
 * Resource Type definition for AWS::Connect::HoursOfOperation
 */
export declare function getHoursOfOperationOutput(args: GetHoursOfOperationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetHoursOfOperationResult>;
export interface GetHoursOfOperationOutputArgs {
    /**
     * The Amazon Resource Name (ARN) for the hours of operation.
     */
    hoursOfOperationArn: pulumi.Input<string>;
}
