import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DataSync::LocationFSxOpenZFS.
 */
export declare class LocationFSxOpenZfs extends pulumi.CustomResource {
    /**
     * Get an existing LocationFSxOpenZfs resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationFSxOpenZfs;
    /**
     * Returns true if the given object is an instance of LocationFSxOpenZfs.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationFSxOpenZfs;
    /**
     * The Amazon Resource Name (ARN) for the FSx OpenZFS file system.
     */
    readonly fsxFilesystemArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon FSx OpenZFS file system location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the FSx OpenZFS that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * The type of protocol that AWS DataSync uses to access your file system.
     */
    readonly protocol: pulumi.Output<outputs.datasync.LocationFSxOpenZfsProtocol>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx OpenZFS file system.
     */
    readonly securityGroupArns: pulumi.Output<string[]>;
    /**
     * A subdirectory in the location's path.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocationFSxOpenZfs resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationFSxOpenZfsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationFSxOpenZfs resource.
 */
export interface LocationFSxOpenZfsArgs {
    /**
     * The Amazon Resource Name (ARN) for the FSx OpenZFS file system.
     */
    fsxFilesystemArn?: pulumi.Input<string>;
    /**
     * The type of protocol that AWS DataSync uses to access your file system.
     */
    protocol: pulumi.Input<inputs.datasync.LocationFSxOpenZfsProtocolArgs>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx OpenZFS file system.
     */
    securityGroupArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A subdirectory in the location's path.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
