import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::DataZone::Environment Resource Type
 */
export declare class Environment extends pulumi.CustomResource {
    /**
     * Get an existing Environment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Environment;
    /**
     * Returns true if the given object is an instance of Environment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Environment;
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * The AWS region in which the Amazon DataZone environment is created.
     */
    readonly awsAccountRegion: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone environment.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp of when the environment was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Amazon DataZone user who created the environment.
     */
    readonly createdBy: pulumi.Output<string>;
    /**
     * The description of the Amazon DataZone environment.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon DataZone domain in which the environment is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the environment would be created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    readonly environmentAccountIdentifier: pulumi.Output<string | undefined>;
    /**
     * The AWS region in which the Amazon DataZone environment is created.
     */
    readonly environmentAccountRegion: pulumi.Output<string | undefined>;
    /**
     * The ID of the blueprint with which the Amazon DataZone environment was created.
     */
    readonly environmentBlueprintId: pulumi.Output<string>;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment was created.
     */
    readonly environmentProfileId: pulumi.Output<string>;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment would be created.
     */
    readonly environmentProfileIdentifier: pulumi.Output<string | undefined>;
    /**
     * Environment role arn for custom aws environment permissions
     */
    readonly environmentRoleArn: pulumi.Output<string | undefined>;
    /**
     * The glossary terms that can be used in the Amazon DataZone environment.
     */
    readonly glossaryTerms: pulumi.Output<string[] | undefined>;
    /**
     * The name of the environment.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone project in which the environment is created.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone project in which the environment would be created.
     */
    readonly projectIdentifier: pulumi.Output<string>;
    /**
     * The provider of the Amazon DataZone environment.
     */
    readonly provider: pulumi.Output<string>;
    /**
     * The status of the Amazon DataZone environment.
     */
    readonly status: pulumi.Output<enums.datazone.EnvironmentStatus>;
    /**
     * The timestamp of when the environment was updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * The user parameters of the Amazon DataZone environment.
     */
    readonly userParameters: pulumi.Output<outputs.datazone.EnvironmentParameter[] | undefined>;
    /**
     * Create a Environment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EnvironmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Environment resource.
 */
export interface EnvironmentArgs {
    /**
     * The description of the Amazon DataZone environment.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the environment would be created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    environmentAccountIdentifier?: pulumi.Input<string>;
    /**
     * The AWS region in which the Amazon DataZone environment is created.
     */
    environmentAccountRegion?: pulumi.Input<string>;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment would be created.
     */
    environmentProfileIdentifier?: pulumi.Input<string>;
    /**
     * Environment role arn for custom aws environment permissions
     */
    environmentRoleArn?: pulumi.Input<string>;
    /**
     * The glossary terms that can be used in the Amazon DataZone environment.
     */
    glossaryTerms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the environment.
     */
    name?: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone project in which the environment would be created.
     */
    projectIdentifier: pulumi.Input<string>;
    /**
     * The user parameters of the Amazon DataZone environment.
     */
    userParameters?: pulumi.Input<pulumi.Input<inputs.datazone.EnvironmentParameterArgs>[]>;
}
