import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DMS::DataProvider
 */
export declare function getDataProvider(args: GetDataProviderArgs, opts?: pulumi.InvokeOptions): Promise<GetDataProviderResult>;
export interface GetDataProviderArgs {
    /**
     * The data provider ARN.
     */
    dataProviderArn: string;
}
export interface GetDataProviderResult {
    /**
     * The data provider ARN.
     */
    readonly dataProviderArn?: string;
    /**
     * The data provider creation time.
     */
    readonly dataProviderCreationTime?: string;
    /**
     * The property describes a name to identify the data provider.
     */
    readonly dataProviderName?: string;
    /**
     * The optional description of the data provider.
     */
    readonly description?: string;
    /**
     * The property describes a data engine for the data provider.
     */
    readonly engine?: enums.dms.DataProviderEngine;
    /**
     * The property identifies the exact type of settings for the data provider.
     */
    readonly settings?: outputs.dms.SettingsProperties;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::DMS::DataProvider
 */
export declare function getDataProviderOutput(args: GetDataProviderOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataProviderResult>;
export interface GetDataProviderOutputArgs {
    /**
     * The data provider ARN.
     */
    dataProviderArn: pulumi.Input<string>;
}
