import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Schema of AWS::EC2::IPAMAllocation Type
 */
export declare function getIpamAllocation(args: GetIpamAllocationArgs, opts?: pulumi.InvokeOptions): Promise<GetIpamAllocationResult>;
export interface GetIpamAllocationArgs {
    /**
     * The CIDR you would like to allocate from the IPAM pool. Note the following:
     *
     * - If there is no DefaultNetmaskLength allocation rule set on the pool, you must specify either the NetmaskLength or the CIDR.
     * - If the DefaultNetmaskLength allocation rule is set on the pool, you can specify either the NetmaskLength or the CIDR and the DefaultNetmaskLength allocation rule will be ignored.
     *
     * Possible values: Any available IPv4 or IPv6 CIDR.
     */
    cidr: string;
    /**
     * Id of the allocation.
     */
    ipamPoolAllocationId: string;
    /**
     * Id of the IPAM Pool.
     */
    ipamPoolId: string;
}
export interface GetIpamAllocationResult {
    /**
     * Id of the allocation.
     */
    readonly ipamPoolAllocationId?: string;
}
/**
 * Resource Schema of AWS::EC2::IPAMAllocation Type
 */
export declare function getIpamAllocationOutput(args: GetIpamAllocationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpamAllocationResult>;
export interface GetIpamAllocationOutputArgs {
    /**
     * The CIDR you would like to allocate from the IPAM pool. Note the following:
     *
     * - If there is no DefaultNetmaskLength allocation rule set on the pool, you must specify either the NetmaskLength or the CIDR.
     * - If the DefaultNetmaskLength allocation rule is set on the pool, you can specify either the NetmaskLength or the CIDR and the DefaultNetmaskLength allocation rule will be ignored.
     *
     * Possible values: Any available IPv4 or IPv6 CIDR.
     */
    cidr: pulumi.Input<string>;
    /**
     * Id of the allocation.
     */
    ipamPoolAllocationId: pulumi.Input<string>;
    /**
     * Id of the IPAM Pool.
     */
    ipamPoolId: pulumi.Input<string>;
}
