import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::VerifiedAccessEndpoint resource creates an AWS EC2 Verified Access Endpoint.
 */
export declare function getVerifiedAccessEndpoint(args: GetVerifiedAccessEndpointArgs, opts?: pulumi.InvokeOptions): Promise<GetVerifiedAccessEndpointResult>;
export interface GetVerifiedAccessEndpointArgs {
    /**
     * The ID of the AWS Verified Access endpoint.
     */
    verifiedAccessEndpointId: string;
}
export interface GetVerifiedAccessEndpointResult {
    /**
     * The options for cidr type endpoint.
     */
    readonly cidrOptions?: outputs.ec2.VerifiedAccessEndpointCidrOptions;
    /**
     * The creation time.
     */
    readonly creationTime?: string;
    /**
     * A description for the AWS Verified Access endpoint.
     */
    readonly description?: string;
    /**
     * Returned if endpoint has a device trust provider attached.
     */
    readonly deviceValidationDomain?: string;
    /**
     * A DNS name that is generated for the endpoint.
     */
    readonly endpointDomain?: string;
    /**
     * The last updated time.
     */
    readonly lastUpdatedTime?: string;
    /**
     * The load balancer details if creating the AWS Verified Access endpoint as load-balancer type.
     */
    readonly loadBalancerOptions?: outputs.ec2.VerifiedAccessEndpointLoadBalancerOptions;
    /**
     * The options for network-interface type endpoint.
     */
    readonly networkInterfaceOptions?: outputs.ec2.VerifiedAccessEndpointNetworkInterfaceOptions;
    /**
     * The AWS Verified Access policy document.
     */
    readonly policyDocument?: string;
    /**
     * The status of the Verified Access policy.
     */
    readonly policyEnabled?: boolean;
    /**
     * The options for rds type endpoint.
     */
    readonly rdsOptions?: outputs.ec2.VerifiedAccessEndpointRdsOptions;
    /**
     * The configuration options for customer provided KMS encryption.
     */
    readonly sseSpecification?: outputs.ec2.VerifiedAccessEndpointSseSpecification;
    /**
     * The endpoint status.
     */
    readonly status?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ID of the AWS Verified Access endpoint.
     */
    readonly verifiedAccessEndpointId?: string;
    /**
     * The ID of the AWS Verified Access group.
     */
    readonly verifiedAccessGroupId?: string;
    /**
     * The ID of the AWS Verified Access instance.
     */
    readonly verifiedAccessInstanceId?: string;
}
/**
 * The AWS::EC2::VerifiedAccessEndpoint resource creates an AWS EC2 Verified Access Endpoint.
 */
export declare function getVerifiedAccessEndpointOutput(args: GetVerifiedAccessEndpointOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVerifiedAccessEndpointResult>;
export interface GetVerifiedAccessEndpointOutputArgs {
    /**
     * The ID of the AWS Verified Access endpoint.
     */
    verifiedAccessEndpointId: pulumi.Input<string>;
}
