import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * An object representing an Amazon EKS IdentityProviderConfig.
 */
export declare function getIdentityProviderConfig(args: GetIdentityProviderConfigArgs, opts?: pulumi.InvokeOptions): Promise<GetIdentityProviderConfigResult>;
export interface GetIdentityProviderConfigArgs {
    /**
     * The name of the identity provider configuration.
     */
    clusterName: string;
    /**
     * The name of the OIDC provider configuration.
     */
    identityProviderConfigName: string;
    /**
     * The type of the identity provider configuration.
     */
    type: enums.eks.IdentityProviderConfigType;
}
export interface GetIdentityProviderConfigResult {
    /**
     * The ARN of the configuration.
     */
    readonly identityProviderConfigArn?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * An object representing an Amazon EKS IdentityProviderConfig.
 */
export declare function getIdentityProviderConfigOutput(args: GetIdentityProviderConfigOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIdentityProviderConfigResult>;
export interface GetIdentityProviderConfigOutputArgs {
    /**
     * The name of the identity provider configuration.
     */
    clusterName: pulumi.Input<string>;
    /**
     * The name of the OIDC provider configuration.
     */
    identityProviderConfigName: pulumi.Input<string>;
    /**
     * The type of the identity provider configuration.
     */
    type: pulumi.Input<enums.eks.IdentityProviderConfigType>;
}
