import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An entity type for fraud detector.
 */
export declare class EntityType extends pulumi.CustomResource {
    /**
     * Get an existing EntityType resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EntityType;
    /**
     * Returns true if the given object is an instance of EntityType.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EntityType;
    /**
     * The entity type ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The timestamp when the entity type was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The entity type description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The timestamp when the entity type was last updated.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The name of the entity type.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags associated with this entity type.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a EntityType resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EntityTypeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EntityType resource.
 */
export interface EntityTypeArgs {
    /**
     * The entity type description.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the entity type.
     */
    name?: pulumi.Input<string>;
    /**
     * Tags associated with this entity type.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
