import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::GameLift::ContainerGroupDefinition resource creates an Amazon GameLift container group definition.
 */
export declare function getContainerGroupDefinition(args: GetContainerGroupDefinitionArgs, opts?: pulumi.InvokeOptions): Promise<GetContainerGroupDefinitionResult>;
export interface GetContainerGroupDefinitionArgs {
    /**
     * A descriptive label for the container group definition.
     */
    name: string;
}
export interface GetContainerGroupDefinitionResult {
    /**
     * The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift container group resource and uniquely identifies it across all AWS Regions.
     */
    readonly containerGroupDefinitionArn?: string;
    /**
     * A time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (for example "1469498468.057").
     */
    readonly creationTime?: string;
    /**
     * The definition for the game server container in this group. This property is used only when the container group type is `GAME_SERVER` . This container definition specifies a container image with the game server build.
     */
    readonly gameServerContainerDefinition?: outputs.gamelift.ContainerGroupDefinitionGameServerContainerDefinition;
    /**
     * The operating system of the container group
     */
    readonly operatingSystem?: enums.gamelift.ContainerGroupDefinitionOperatingSystem;
    /**
     * A string indicating ContainerGroupDefinition status.
     */
    readonly status?: enums.gamelift.ContainerGroupDefinitionStatus;
    /**
     * A string indicating the reason for ContainerGroupDefinition status.
     */
    readonly statusReason?: string;
    /**
     * A collection of support container definitions that define the containers in this group.
     */
    readonly supportContainerDefinitions?: outputs.gamelift.ContainerGroupDefinitionSupportContainerDefinition[];
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The total memory limit of container groups following this definition in MiB
     */
    readonly totalMemoryLimitMebibytes?: number;
    /**
     * The total amount of virtual CPUs on the container group definition
     */
    readonly totalVcpuLimit?: number;
    /**
     * The description of this version
     */
    readonly versionDescription?: string;
    /**
     * The version of this ContainerGroupDefinition
     */
    readonly versionNumber?: number;
}
/**
 * The AWS::GameLift::ContainerGroupDefinition resource creates an Amazon GameLift container group definition.
 */
export declare function getContainerGroupDefinitionOutput(args: GetContainerGroupDefinitionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetContainerGroupDefinitionResult>;
export interface GetContainerGroupDefinitionOutputArgs {
    /**
     * A descriptive label for the container group definition.
     */
    name: pulumi.Input<string>;
}
