import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::GameLift::MatchmakingConfiguration resource creates an Amazon GameLift (GameLift) matchmaking configuration.
 */
export declare class MatchmakingConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing MatchmakingConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MatchmakingConfiguration;
    /**
     * Returns true if the given object is an instance of MatchmakingConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MatchmakingConfiguration;
    /**
     * A flag that indicates whether a match that was created with this configuration must be accepted by the matched players
     */
    readonly acceptanceRequired: pulumi.Output<boolean>;
    /**
     * The length of time (in seconds) to wait for players to accept a proposed match, if acceptance is required.
     */
    readonly acceptanceTimeoutSeconds: pulumi.Output<number | undefined>;
    /**
     * The number of player slots in a match to keep open for future players.
     */
    readonly additionalPlayerCount: pulumi.Output<number | undefined>;
    /**
     * The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift matchmaking configuration resource and uniquely identifies it.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The method used to backfill game sessions created with this matchmaking configuration.
     */
    readonly backfillMode: pulumi.Output<enums.gamelift.MatchmakingConfigurationBackfillMode | undefined>;
    /**
     * A time stamp indicating when this data object was created.
     */
    readonly creationTime: pulumi.Output<string | undefined>;
    /**
     * Information to attach to all events related to the matchmaking configuration.
     */
    readonly customEventData: pulumi.Output<string | undefined>;
    /**
     * A descriptive label that is associated with matchmaking configuration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Indicates whether this matchmaking configuration is being used with Amazon GameLift hosting or as a standalone matchmaking solution.
     */
    readonly flexMatchMode: pulumi.Output<enums.gamelift.MatchmakingConfigurationFlexMatchMode | undefined>;
    /**
     * A set of custom properties for a game session, formatted as key:value pairs.
     */
    readonly gameProperties: pulumi.Output<outputs.gamelift.MatchmakingConfigurationGameProperty[] | undefined>;
    /**
     * A set of custom game session properties, formatted as a single string value.
     */
    readonly gameSessionData: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift game session queue resource and uniquely identifies it.
     */
    readonly gameSessionQueueArns: pulumi.Output<string[] | undefined>;
    /**
     * A unique identifier for the matchmaking configuration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An SNS topic ARN that is set up to receive matchmaking notifications.
     */
    readonly notificationTarget: pulumi.Output<string | undefined>;
    /**
     * The maximum duration, in seconds, that a matchmaking ticket can remain in process before timing out.
     */
    readonly requestTimeoutSeconds: pulumi.Output<number>;
    /**
     * The Amazon Resource Name (ARN) associated with the GameLift matchmaking rule set resource that this configuration uses.
     */
    readonly ruleSetArn: pulumi.Output<string | undefined>;
    /**
     * A unique identifier for the matchmaking rule set to use with this configuration.
     */
    readonly ruleSetName: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MatchmakingConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MatchmakingConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MatchmakingConfiguration resource.
 */
export interface MatchmakingConfigurationArgs {
    /**
     * A flag that indicates whether a match that was created with this configuration must be accepted by the matched players
     */
    acceptanceRequired: pulumi.Input<boolean>;
    /**
     * The length of time (in seconds) to wait for players to accept a proposed match, if acceptance is required.
     */
    acceptanceTimeoutSeconds?: pulumi.Input<number>;
    /**
     * The number of player slots in a match to keep open for future players.
     */
    additionalPlayerCount?: pulumi.Input<number>;
    /**
     * The method used to backfill game sessions created with this matchmaking configuration.
     */
    backfillMode?: pulumi.Input<enums.gamelift.MatchmakingConfigurationBackfillMode>;
    /**
     * A time stamp indicating when this data object was created.
     */
    creationTime?: pulumi.Input<string>;
    /**
     * Information to attach to all events related to the matchmaking configuration.
     */
    customEventData?: pulumi.Input<string>;
    /**
     * A descriptive label that is associated with matchmaking configuration.
     */
    description?: pulumi.Input<string>;
    /**
     * Indicates whether this matchmaking configuration is being used with Amazon GameLift hosting or as a standalone matchmaking solution.
     */
    flexMatchMode?: pulumi.Input<enums.gamelift.MatchmakingConfigurationFlexMatchMode>;
    /**
     * A set of custom properties for a game session, formatted as key:value pairs.
     */
    gameProperties?: pulumi.Input<pulumi.Input<inputs.gamelift.MatchmakingConfigurationGamePropertyArgs>[]>;
    /**
     * A set of custom game session properties, formatted as a single string value.
     */
    gameSessionData?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift game session queue resource and uniquely identifies it.
     */
    gameSessionQueueArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A unique identifier for the matchmaking configuration.
     */
    name?: pulumi.Input<string>;
    /**
     * An SNS topic ARN that is set up to receive matchmaking notifications.
     */
    notificationTarget?: pulumi.Input<string>;
    /**
     * The maximum duration, in seconds, that a matchmaking ticket can remain in process before timing out.
     */
    requestTimeoutSeconds: pulumi.Input<number>;
    /**
     * The Amazon Resource Name (ARN) associated with the GameLift matchmaking rule set resource that this configuration uses.
     */
    ruleSetArn?: pulumi.Input<string>;
    /**
     * A unique identifier for the matchmaking rule set to use with this configuration.
     */
    ruleSetName: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
