import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::GameLiftStreams::StreamGroup Resource Type
 */
export declare function getStreamGroup(args: GetStreamGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamGroupResult>;
export interface GetStreamGroupArgs {
    /**
     * An [Amazon Resource Name (ARN)](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html) that uniquely identifies the stream group resource. For example: `arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/sg-1AB2C3De4` .
     */
    arn: string;
}
export interface GetStreamGroupResult {
    /**
     * An [Amazon Resource Name (ARN)](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html) that uniquely identifies the stream group resource. For example: `arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/sg-1AB2C3De4` .
     */
    readonly arn?: string;
    /**
     * Object that identifies the Amazon GameLift Streams application to stream with this stream group.
     */
    readonly defaultApplication?: outputs.gameliftstreams.StreamGroupDefaultApplication;
    /**
     * A descriptive label for the stream group.
     */
    readonly description?: string;
    /**
     * An ID that uniquely identifies the stream group resource. For example: `sg-1AB2C3De4` .
     */
    readonly id?: string;
    /**
     * A set of one or more locations and the streaming capacity for each location. One of the locations MUST be your primary location, which is the AWS Region where you are specifying this resource.
     */
    readonly locationConfigurations?: outputs.gameliftstreams.StreamGroupLocationConfiguration[];
    /**
     * A list of labels to assign to the new stream group resource. Tags are developer-defined key-value pairs. Tagging AWS resources is useful for resource management, access management and cost allocation. See [Tagging AWS Resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in the *AWS General Reference* .
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Definition of AWS::GameLiftStreams::StreamGroup Resource Type
 */
export declare function getStreamGroupOutput(args: GetStreamGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamGroupResult>;
export interface GetStreamGroupOutputArgs {
    /**
     * An [Amazon Resource Name (ARN)](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html) that uniquely identifies the stream group resource. For example: `arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/sg-1AB2C3De4` .
     */
    arn: pulumi.Input<string>;
}
