import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GlobalAccelerator::CrossAccountAttachment
 */
export declare class CrossAccountAttachment extends pulumi.CustomResource {
    /**
     * Get an existing CrossAccountAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CrossAccountAttachment;
    /**
     * Returns true if the given object is an instance of CrossAccountAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CrossAccountAttachment;
    /**
     * The Amazon Resource Name (ARN) of the attachment.
     */
    readonly attachmentArn: pulumi.Output<string>;
    /**
     * The Friendly identifier of the attachment.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Principals to share the resources with.
     */
    readonly principals: pulumi.Output<string[] | undefined>;
    /**
     * Resources shared using the attachment.
     */
    readonly resources: pulumi.Output<outputs.globalaccelerator.CrossAccountAttachmentResource[] | undefined>;
    /**
     * Add tags for a cross-account attachment.
     *
     * For more information, see [Tagging in AWS Global Accelerator](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html) in the *AWS Global Accelerator Developer Guide* .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CrossAccountAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: CrossAccountAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CrossAccountAttachment resource.
 */
export interface CrossAccountAttachmentArgs {
    /**
     * The Friendly identifier of the attachment.
     */
    name?: pulumi.Input<string>;
    /**
     * Principals to share the resources with.
     */
    principals?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Resources shared using the attachment.
     */
    resources?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.CrossAccountAttachmentResourceArgs>[]>;
    /**
     * Add tags for a cross-account attachment.
     *
     * For more information, see [Tagging in AWS Global Accelerator](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html) in the *AWS Global Accelerator Developer Guide* .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
