import * as pulumi from "@pulumi/pulumi";
/**
 * Resource for Greengrass V2 deployment.
 */
export declare function getDeployment(args: GetDeploymentArgs, opts?: pulumi.InvokeOptions): Promise<GetDeploymentResult>;
export interface GetDeploymentArgs {
    /**
     * The ID of the deployment.
     */
    deploymentId: string;
}
export interface GetDeploymentResult {
    /**
     * The ID of the deployment.
     */
    readonly deploymentId?: string;
    /**
     * Application-specific metadata to attach to the deployment. You can use tags in IAM policies to control access to AWS IoT Greengrass resources. You can also use tags to categorize your resources. For more information, see [Tag your AWS IoT Greengrass Version 2 resources](https://docs.aws.amazon.com/greengrass/v2/developerguide/tag-resources.html) in the *AWS IoT Greengrass V2 Developer Guide* .
     *
     * This `Json` property type is processed as a map of key-value pairs. It uses the following format, which is different from most `Tags` implementations in AWS CloudFormation templates.
     *
     * ```json
     * "Tags": { "KeyName0": "value", "KeyName1": "value", "KeyName2": "value"
     * }
     * ```
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Resource for Greengrass V2 deployment.
 */
export declare function getDeploymentOutput(args: GetDeploymentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDeploymentResult>;
export interface GetDeploymentOutputArgs {
    /**
     * The ID of the deployment.
     */
    deploymentId: pulumi.Input<string>;
}
