import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GuardDuty::IPSet
 */
export declare function getIpSet(args: GetIpSetArgs, opts?: pulumi.InvokeOptions): Promise<GetIpSetResult>;
export interface GetIpSetArgs {
    /**
     * The unique ID of the detector of the GuardDuty account for which you want to create an IPSet.
     *
     * To find the `detectorId` in the current Region, see the
     * Settings page in the GuardDuty console, or run the [ListDetectors](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html) API.
     */
    detectorId: string;
    id: string;
}
export interface GetIpSetResult {
    readonly id?: string;
    /**
     * The URI of the file that contains the IPSet.
     */
    readonly location?: string;
    /**
     * The user-friendly name to identify the IPSet.
     *
     * Allowed characters are alphanumeric, whitespace, dash (-), and underscores (_).
     */
    readonly name?: string;
    /**
     * The tags to be added to a new IP set resource. Each tag consists of a key and an optional value, both of which you define.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::GuardDuty::IPSet
 */
export declare function getIpSetOutput(args: GetIpSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpSetResult>;
export interface GetIpSetOutputArgs {
    /**
     * The unique ID of the detector of the GuardDuty account for which you want to create an IPSet.
     *
     * To find the `detectorId` in the current Region, see the
     * Settings page in the GuardDuty console, or run the [ListDetectors](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html) API.
     */
    detectorId: pulumi.Input<string>;
    id: pulumi.Input<string>;
}
