import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IoT::ThingGroup
 */
export declare class ThingGroup extends pulumi.CustomResource {
    /**
     * Get an existing ThingGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ThingGroup;
    /**
     * Returns true if the given object is an instance of ThingGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ThingGroup;
    /**
     * The thing group ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The thing group ID.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The parent thing group name.
     *
     * A Dynamic Thing Group does not have `parentGroupName` defined.
     */
    readonly parentGroupName: pulumi.Output<string | undefined>;
    /**
     * The dynamic thing group search query string.
     *
     * The `queryString` attribute *is* required for `CreateDynamicThingGroup` . The `queryString` attribute *is not* required for `CreateThingGroup` .
     */
    readonly queryString: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The thing group name.
     */
    readonly thingGroupName: pulumi.Output<string | undefined>;
    /**
     * Thing group properties.
     */
    readonly thingGroupProperties: pulumi.Output<outputs.iot.ThingGroupPropertiesProperties | undefined>;
    /**
     * Create a ThingGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ThingGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ThingGroup resource.
 */
export interface ThingGroupArgs {
    /**
     * The parent thing group name.
     *
     * A Dynamic Thing Group does not have `parentGroupName` defined.
     */
    parentGroupName?: pulumi.Input<string>;
    /**
     * The dynamic thing group search query string.
     *
     * The `queryString` attribute *is* required for `CreateDynamicThingGroup` . The `queryString` attribute *is not* required for `CreateThingGroup` .
     */
    queryString?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The thing group name.
     */
    thingGroupName?: pulumi.Input<string>;
    /**
     * Thing group properties.
     */
    thingGroupProperties?: pulumi.Input<inputs.iot.ThingGroupPropertiesPropertiesArgs>;
}
