import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTSiteWise::Gateway
 */
export declare class Gateway extends pulumi.CustomResource {
    /**
     * Get an existing Gateway resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Gateway;
    /**
     * Returns true if the given object is an instance of Gateway.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Gateway;
    /**
     * A list of gateway capability summaries that each contain a namespace and status.
     */
    readonly gatewayCapabilitySummaries: pulumi.Output<outputs.iotsitewise.GatewayCapabilitySummary[] | undefined>;
    /**
     * The ID of the gateway device.
     */
    readonly gatewayId: pulumi.Output<string>;
    /**
     * A unique, friendly name for the gateway.
     */
    readonly gatewayName: pulumi.Output<string>;
    /**
     * The gateway's platform. You can only specify one platform in a gateway.
     */
    readonly gatewayPlatform: pulumi.Output<outputs.iotsitewise.GatewayPlatform>;
    /**
     * The version of the gateway you want to create.
     */
    readonly gatewayVersion: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the gateway.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Gateway resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GatewayArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Gateway resource.
 */
export interface GatewayArgs {
    /**
     * A list of gateway capability summaries that each contain a namespace and status.
     */
    gatewayCapabilitySummaries?: pulumi.Input<pulumi.Input<inputs.iotsitewise.GatewayCapabilitySummaryArgs>[]>;
    /**
     * A unique, friendly name for the gateway.
     */
    gatewayName?: pulumi.Input<string>;
    /**
     * The gateway's platform. You can only specify one platform in a gateway.
     */
    gatewayPlatform: pulumi.Input<inputs.iotsitewise.GatewayPlatformArgs>;
    /**
     * The version of the gateway you want to create.
     */
    gatewayVersion?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the gateway.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
