import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IVS::EncoderConfiguration.
 */
export declare class EncoderConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing EncoderConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EncoderConfiguration;
    /**
     * Returns true if the given object is an instance of EncoderConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EncoderConfiguration;
    /**
     * Encoder configuration identifier.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Encoder configuration name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Video configuration. Default: video resolution 1280x720, bitrate 2500 kbps, 30 fps
     */
    readonly video: pulumi.Output<outputs.ivs.VideoProperties | undefined>;
    /**
     * Create a EncoderConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EncoderConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EncoderConfiguration resource.
 */
export interface EncoderConfigurationArgs {
    /**
     * Encoder configuration name.
     */
    name?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Video configuration. Default: video resolution 1280x720, bitrate 2500 kbps, 30 fps
     */
    video?: pulumi.Input<inputs.ivs.VideoPropertiesArgs>;
}
