import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::Logs::Destination resource specifies a CloudWatch Logs destination. A destination encapsulates a physical resource (such as an Amazon Kinesis data stream) and enables you to subscribe that resource to a stream of log events.
 */
export declare class Destination extends pulumi.CustomResource {
    /**
     * Get an existing Destination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Destination;
    /**
     * Returns true if the given object is an instance of Destination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Destination;
    /**
     * The ARN of the CloudWatch Logs destination, such as `arn:aws:logs:us-west-1:123456789012:destination:MyDestination` .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the destination resource
     */
    readonly destinationName: pulumi.Output<string>;
    /**
     * An IAM policy document that governs which AWS accounts can create subscription filters against this destination.
     */
    readonly destinationPolicy: pulumi.Output<string | undefined>;
    /**
     * The ARN of an IAM role that permits CloudWatch Logs to send data to the specified AWS resource
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The ARN of the physical target where the log events are delivered (for example, a Kinesis stream)
     */
    readonly targetArn: pulumi.Output<string>;
    /**
     * Create a Destination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Destination resource.
 */
export interface DestinationArgs {
    /**
     * The name of the destination resource
     */
    destinationName?: pulumi.Input<string>;
    /**
     * An IAM policy document that governs which AWS accounts can create subscription filters against this destination.
     */
    destinationPolicy?: pulumi.Input<string>;
    /**
     * The ARN of an IAM role that permits CloudWatch Logs to send data to the specified AWS resource
     */
    roleArn: pulumi.Input<string>;
    /**
     * The ARN of the physical target where the log events are delivered (for example, a Kinesis stream)
     */
    targetArn: pulumi.Input<string>;
}
