import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::NetworkManager::VpcAttachment Resoruce Type
 */
export declare class VpcAttachment extends pulumi.CustomResource {
    /**
     * Get an existing VpcAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcAttachment;
    /**
     * Returns true if the given object is an instance of VpcAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcAttachment;
    /**
     * Id of the attachment.
     */
    readonly attachmentId: pulumi.Output<string>;
    /**
     * The policy rule number associated with the attachment.
     */
    readonly attachmentPolicyRuleNumber: pulumi.Output<number>;
    /**
     * Attachment type.
     */
    readonly attachmentType: pulumi.Output<string>;
    /**
     * The ARN of a core network for the VPC attachment.
     */
    readonly coreNetworkArn: pulumi.Output<string>;
    /**
     * The ID of a core network for the VPC attachment.
     */
    readonly coreNetworkId: pulumi.Output<string>;
    /**
     * Creation time of the attachment.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Region where the edge is located.
     */
    readonly edgeLocation: pulumi.Output<string>;
    /**
     * The name of the network function group attachment.
     */
    readonly networkFunctionGroupName: pulumi.Output<string>;
    /**
     * Vpc options of the attachment.
     */
    readonly options: pulumi.Output<outputs.networkmanager.VpcAttachmentVpcOptions | undefined>;
    /**
     * Owner account of the attachment.
     */
    readonly ownerAccountId: pulumi.Output<string>;
    /**
     * The attachment to move from one network function group to another.
     */
    readonly proposedNetworkFunctionGroupChange: pulumi.Output<outputs.networkmanager.VpcAttachmentProposedNetworkFunctionGroupChange | undefined>;
    /**
     * The attachment to move from one segment to another.
     */
    readonly proposedSegmentChange: pulumi.Output<outputs.networkmanager.VpcAttachmentProposedSegmentChange | undefined>;
    /**
     * The ARN of the Resource.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The name of the segment attachment..
     */
    readonly segmentName: pulumi.Output<string>;
    /**
     * State of the attachment.
     */
    readonly state: pulumi.Output<string>;
    /**
     * Subnet Arn list
     */
    readonly subnetArns: pulumi.Output<string[]>;
    /**
     * Tags for the attachment.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Last update time of the attachment.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * The ARN of the VPC.
     */
    readonly vpcArn: pulumi.Output<string>;
    /**
     * Create a VpcAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcAttachment resource.
 */
export interface VpcAttachmentArgs {
    /**
     * The ID of a core network for the VPC attachment.
     */
    coreNetworkId: pulumi.Input<string>;
    /**
     * Vpc options of the attachment.
     */
    options?: pulumi.Input<inputs.networkmanager.VpcAttachmentVpcOptionsArgs>;
    /**
     * The attachment to move from one network function group to another.
     */
    proposedNetworkFunctionGroupChange?: pulumi.Input<inputs.networkmanager.VpcAttachmentProposedNetworkFunctionGroupChangeArgs>;
    /**
     * The attachment to move from one segment to another.
     */
    proposedSegmentChange?: pulumi.Input<inputs.networkmanager.VpcAttachmentProposedSegmentChangeArgs>;
    /**
     * Subnet Arn list
     */
    subnetArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Tags for the attachment.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ARN of the VPC.
     */
    vpcArn: pulumi.Input<string>;
}
