import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::NimbleStudio::LaunchProfile
 */
export declare class LaunchProfile extends pulumi.CustomResource {
    /**
     * Get an existing LaunchProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LaunchProfile;
    /**
     * Returns true if the given object is an instance of LaunchProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LaunchProfile;
    /**
     * A human-readable description of the launch profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Unique identifiers for a collection of EC2 subnets.
     */
    readonly ec2SubnetIds: pulumi.Output<string[]>;
    /**
     * The unique identifier for the launch profile resource.
     */
    readonly launchProfileId: pulumi.Output<string>;
    /**
     * The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31".
     */
    readonly launchProfileProtocolVersions: pulumi.Output<string[]>;
    /**
     * A friendly name for the launch profile.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A configuration for a streaming session.
     */
    readonly streamConfiguration: pulumi.Output<outputs.nimblestudio.LaunchProfileStreamConfiguration>;
    /**
     * Unique identifiers for a collection of studio components that can be used with this launch profile.
     */
    readonly studioComponentIds: pulumi.Output<string[]>;
    /**
     * The unique identifier for a studio resource. In Nimble Studio, all other resources are contained in a studio resource.
     */
    readonly studioId: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a LaunchProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LaunchProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LaunchProfile resource.
 */
export interface LaunchProfileArgs {
    /**
     * A human-readable description of the launch profile.
     */
    description?: pulumi.Input<string>;
    /**
     * Unique identifiers for a collection of EC2 subnets.
     */
    ec2SubnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31".
     */
    launchProfileProtocolVersions: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A friendly name for the launch profile.
     */
    name?: pulumi.Input<string>;
    /**
     * A configuration for a streaming session.
     */
    streamConfiguration: pulumi.Input<inputs.nimblestudio.LaunchProfileStreamConfigurationArgs>;
    /**
     * Unique identifiers for a collection of studio components that can be used with this launch profile.
     */
    studioComponentIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The unique identifier for a studio resource. In Nimble Studio, all other resources are contained in a studio resource.
     */
    studioId: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
