import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::NimbleStudio::StreamingImage
 */
export declare class StreamingImage extends pulumi.CustomResource {
    /**
     * Get an existing StreamingImage resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StreamingImage;
    /**
     * Returns true if the given object is an instance of StreamingImage.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StreamingImage;
    /**
     * A human-readable description of the streaming image.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of an EC2 machine image with which to create the streaming image.
     */
    readonly ec2ImageId: pulumi.Output<string>;
    readonly encryptionConfiguration: pulumi.Output<outputs.nimblestudio.StreamingImageEncryptionConfiguration>;
    readonly encryptionConfigurationKeyArn: pulumi.Output<string | undefined>;
    readonly encryptionConfigurationKeyType: pulumi.Output<string | undefined>;
    /**
     * The list of IDs of EULAs that must be accepted before a streaming session can be started using this streaming image.
     */
    readonly eulaIds: pulumi.Output<string[]>;
    /**
     * A friendly name for a streaming image resource.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The owner of the streaming image, either the studioId that contains the streaming image or 'amazon' for images that are provided by  .
     */
    readonly owner: pulumi.Output<string>;
    /**
     * The platform of the streaming image, either WINDOWS or LINUX.
     */
    readonly platform: pulumi.Output<string>;
    /**
     * The unique identifier for the streaming image resource.
     */
    readonly streamingImageId: pulumi.Output<string>;
    /**
     * The unique identifier for a studio resource. In Nimble Studio, all other resources are contained in a studio resource.
     */
    readonly studioId: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a StreamingImage resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StreamingImageArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StreamingImage resource.
 */
export interface StreamingImageArgs {
    /**
     * A human-readable description of the streaming image.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of an EC2 machine image with which to create the streaming image.
     */
    ec2ImageId: pulumi.Input<string>;
    encryptionConfigurationKeyArn?: pulumi.Input<string>;
    encryptionConfigurationKeyType?: pulumi.Input<string>;
    /**
     * A friendly name for a streaming image resource.
     */
    name?: pulumi.Input<string>;
    /**
     * The unique identifier for a studio resource. In Nimble Studio, all other resources are contained in a studio resource.
     */
    studioId: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
