import * as pulumi from "@pulumi/pulumi";
/**
 * Represents a SCEP Challenge that is used for certificate enrollment
 */
export declare class Challenge extends pulumi.CustomResource {
    /**
     * Get an existing Challenge resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Challenge;
    /**
     * Returns true if the given object is an instance of Challenge.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Challenge;
    /**
     * The Amazon Resource Name (ARN) of the challenge.
     */
    readonly challengeArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the connector.
     */
    readonly connectorArn: pulumi.Output<string>;
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Challenge resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ChallengeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Challenge resource.
 */
export interface ChallengeArgs {
    /**
     * The Amazon Resource Name (ARN) of the connector.
     */
    connectorArn: pulumi.Input<string>;
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
