import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Proton::EnvironmentTemplate Resource Type
 */
export declare class EnvironmentTemplate extends pulumi.CustomResource {
    /**
     * Get an existing EnvironmentTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EnvironmentTemplate;
    /**
     * Returns true if the given object is an instance of EnvironmentTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EnvironmentTemplate;
    /**
     * <p>The Amazon Resource Name (ARN) of the environment template.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * <p>A description of the environment template.</p>
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * <p>The environment template name as displayed in the developer interface.</p>
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * <p>A customer provided encryption key that Proton uses to encrypt data.</p>
     */
    readonly encryptionKey: pulumi.Output<string | undefined>;
    /**
     * The name of the environment template.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * When included, indicates that the environment template is for customer provisioned and managed infrastructure.
     */
    readonly provisioning: pulumi.Output<enums.proton.EnvironmentTemplateProvisioning | undefined>;
    /**
     * <p>An optional list of metadata items that you can associate with the Proton environment template. A tag is a key-value pair.</p>
     *          <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">Proton resources and tagging</a> in the
     *         <i>Proton User Guide</i>.</p>
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a EnvironmentTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EnvironmentTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EnvironmentTemplate resource.
 */
export interface EnvironmentTemplateArgs {
    /**
     * <p>A description of the environment template.</p>
     */
    description?: pulumi.Input<string>;
    /**
     * <p>The environment template name as displayed in the developer interface.</p>
     */
    displayName?: pulumi.Input<string>;
    /**
     * <p>A customer provided encryption key that Proton uses to encrypt data.</p>
     */
    encryptionKey?: pulumi.Input<string>;
    /**
     * The name of the environment template.
     */
    name?: pulumi.Input<string>;
    /**
     * When included, indicates that the environment template is for customer provisioned and managed infrastructure.
     */
    provisioning?: pulumi.Input<enums.proton.EnvironmentTemplateProvisioning>;
    /**
     * <p>An optional list of metadata items that you can associate with the Proton environment template. A tag is a key-value pair.</p>
     *          <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">Proton resources and tagging</a> in the
     *         <i>Proton User Guide</i>.</p>
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
