import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::RDS::DBSubnetGroup`` resource creates a database subnet group. Subnet groups must contain at least two subnets in two different Availability Zones in the same region.
 *  For more information, see [Working with DB subnet groups](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.WorkingWithRDSInstanceinaVPC.html#USER_VPC.Subnets) in the *Amazon RDS User Guide*.
 */
export declare function getDbSubnetGroup(args: GetDbSubnetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetDbSubnetGroupResult>;
export interface GetDbSubnetGroupArgs {
    /**
     * The name for the DB subnet group. This value is stored as a lowercase string.
     *  Constraints:
     *   +  Must contain no more than 255 letters, numbers, periods, underscores, spaces, or hyphens.
     *   +  Must not be default.
     *   +  First character must be a letter.
     *
     *  Example: ``mydbsubnetgroup``
     */
    dbSubnetGroupName: string;
}
export interface GetDbSubnetGroupResult {
    /**
     * The description for the DB subnet group.
     */
    readonly dbSubnetGroupDescription?: string;
    /**
     * The EC2 Subnet IDs for the DB subnet group.
     */
    readonly subnetIds?: string[];
    /**
     * Tags to assign to the DB subnet group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The ``AWS::RDS::DBSubnetGroup`` resource creates a database subnet group. Subnet groups must contain at least two subnets in two different Availability Zones in the same region.
 *  For more information, see [Working with DB subnet groups](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.WorkingWithRDSInstanceinaVPC.html#USER_VPC.Subnets) in the *Amazon RDS User Guide*.
 */
export declare function getDbSubnetGroupOutput(args: GetDbSubnetGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbSubnetGroupResult>;
export interface GetDbSubnetGroupOutputArgs {
    /**
     * The name for the DB subnet group. This value is stored as a lowercase string.
     *  Constraints:
     *   +  Must contain no more than 255 letters, numbers, periods, underscores, spaces, or hyphens.
     *   +  Must not be default.
     *   +  First character must be a letter.
     *
     *  Example: ``mydbsubnetgroup``
     */
    dbSubnetGroupName: pulumi.Input<string>;
}
