import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Aws Route53 Recovery Readiness Check Schema and API specification.
 */
export declare class ReadinessCheck extends pulumi.CustomResource {
    /**
     * Get an existing ReadinessCheck resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ReadinessCheck;
    /**
     * Returns true if the given object is an instance of ReadinessCheck.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReadinessCheck;
    /**
     * The Amazon Resource Name (ARN) of the readiness check.
     */
    readonly readinessCheckArn: pulumi.Output<string>;
    /**
     * Name of the ReadinessCheck to create.
     */
    readonly readinessCheckName: pulumi.Output<string | undefined>;
    /**
     * The name of the resource set to check.
     */
    readonly resourceSetName: pulumi.Output<string | undefined>;
    /**
     * A collection of tags associated with a resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ReadinessCheck resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ReadinessCheckArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ReadinessCheck resource.
 */
export interface ReadinessCheckArgs {
    /**
     * Name of the ReadinessCheck to create.
     */
    readinessCheckName?: pulumi.Input<string>;
    /**
     * The name of the resource set to check.
     */
    resourceSetName?: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
