import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::Cluster
 */
export declare function getCluster(args: GetClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetClusterResult>;
export interface GetClusterArgs {
    /**
     * The Amazon Resource Name (ARN) of the HyperPod Cluster.
     */
    clusterArn: string;
}
export interface GetClusterResult {
    /**
     * The Amazon Resource Name (ARN) of the HyperPod Cluster.
     */
    readonly clusterArn?: string;
    /**
     * The status of the HyperPod Cluster.
     */
    readonly clusterStatus?: enums.sagemaker.ClusterStatus;
    /**
     * The time at which the HyperPod cluster was created.
     */
    readonly creationTime?: string;
    /**
     * The failure message of the HyperPod Cluster.
     */
    readonly failureMessage?: string;
    /**
     * The instance groups of the SageMaker HyperPod cluster. To delete an instance group, remove it from the array.
     */
    readonly instanceGroups?: outputs.sagemaker.ClusterInstanceGroup[];
    /**
     * If node auto-recovery is set to true, faulty nodes will be replaced or rebooted when a failure is detected. If set to false, nodes will be labelled when a fault is detected.
     */
    readonly nodeRecovery?: enums.sagemaker.ClusterNodeRecovery;
    /**
     * Custom tags for managing the SageMaker HyperPod cluster as an AWS resource. You can add tags to your cluster in the same way you add them in other AWS services that support tagging.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::SageMaker::Cluster
 */
export declare function getClusterOutput(args: GetClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetClusterResult>;
export interface GetClusterOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the HyperPod Cluster.
     */
    clusterArn: pulumi.Input<string>;
}
