import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::SecurityHub::Standard`` resource specifies the enablement of a security standard. The standard is identified by the ``StandardsArn`` property. To view a list of ASH standards and their Amazon Resource Names (ARNs), use the [DescribeStandards](https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandards.html) API operation.
 *  You must create a separate ``AWS::SecurityHub::Standard`` resource for each standard that you want to enable.
 *  For more information about ASH standards, see [standards reference](https://docs.aws.amazon.com/securityhub/latest/userguide/standards-reference.html) in the *User Guide*.
 */
export declare function getStandard(args: GetStandardArgs, opts?: pulumi.InvokeOptions): Promise<GetStandardResult>;
export interface GetStandardArgs {
    /**
     * The ARN of a resource that represents your subscription to a supported standard.
     */
    standardsSubscriptionArn: string;
}
export interface GetStandardResult {
    /**
     * Specifies which controls are to be disabled in a standard.
     *   *Maximum*: ``100``
     */
    readonly disabledStandardsControls?: outputs.securityhub.StandardsControl[];
    /**
     * The ARN of a resource that represents your subscription to a supported standard.
     */
    readonly standardsSubscriptionArn?: string;
}
/**
 * The ``AWS::SecurityHub::Standard`` resource specifies the enablement of a security standard. The standard is identified by the ``StandardsArn`` property. To view a list of ASH standards and their Amazon Resource Names (ARNs), use the [DescribeStandards](https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandards.html) API operation.
 *  You must create a separate ``AWS::SecurityHub::Standard`` resource for each standard that you want to enable.
 *  For more information about ASH standards, see [standards reference](https://docs.aws.amazon.com/securityhub/latest/userguide/standards-reference.html) in the *User Guide*.
 */
export declare function getStandardOutput(args: GetStandardOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStandardResult>;
export interface GetStandardOutputArgs {
    /**
     * The ARN of a resource that represents your subscription to a supported standard.
     */
    standardsSubscriptionArn: pulumi.Input<string>;
}
