import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::SSMQuickSetup::ConfigurationManager Resource Type
 */
export declare class ConfigurationManager extends pulumi.CustomResource {
    /**
     * Get an existing ConfigurationManager resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConfigurationManager;
    /**
     * Returns true if the given object is an instance of ConfigurationManager.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConfigurationManager;
    /**
     * The definition of the Quick Setup configuration that the configuration manager deploys.
     */
    readonly configurationDefinitions: pulumi.Output<outputs.ssmquicksetup.ConfigurationManagerConfigurationDefinition[]>;
    /**
     * The datetime stamp when the configuration manager was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the configuration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The datetime stamp when the configuration manager was last updated.
     */
    readonly lastModifiedAt: pulumi.Output<string>;
    /**
     * The ARN of the Quick Setup configuration.
     */
    readonly managerArn: pulumi.Output<string>;
    /**
     * The name of the configuration
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Summaries of the state of the configuration manager. These summaries include an aggregate of the statuses from the configuration definition associated with the configuration manager. This includes deployment statuses, association statuses, drift statuses, health checks, and more.
     */
    readonly statusSummaries: pulumi.Output<outputs.ssmquicksetup.ConfigurationManagerStatusSummary[]>;
    /**
     * Key-value pairs of metadata to assign to the configuration manager.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a ConfigurationManager resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConfigurationManagerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConfigurationManager resource.
 */
export interface ConfigurationManagerArgs {
    /**
     * The definition of the Quick Setup configuration that the configuration manager deploys.
     */
    configurationDefinitions: pulumi.Input<pulumi.Input<inputs.ssmquicksetup.ConfigurationManagerConfigurationDefinitionArgs>[]>;
    /**
     * The description of the configuration.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the configuration
     */
    name?: pulumi.Input<string>;
    /**
     * Key-value pairs of metadata to assign to the configuration manager.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
