import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for Identity Center (SSO) Application
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The Application ARN that is returned upon creation of the Identity Center (SSO) Application
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * The ARN of the application provider under which the operation will run
     */
    readonly applicationProviderArn: pulumi.Output<string>;
    /**
     * The description information for the Identity Center (SSO) Application
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ARN of the instance of IAM Identity Center under which the operation will run
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name you want to assign to this Identity Center (SSO) Application
     */
    readonly name: pulumi.Output<string>;
    /**
     * A structure that describes the options for the portal associated with an application
     */
    readonly portalOptions: pulumi.Output<outputs.sso.ApplicationPortalOptionsConfiguration | undefined>;
    /**
     * Specifies whether the application is enabled or disabled
     */
    readonly status: pulumi.Output<enums.sso.ApplicationStatus | undefined>;
    /**
     * Specifies tags to be attached to the application
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The ARN of the application provider under which the operation will run
     */
    applicationProviderArn: pulumi.Input<string>;
    /**
     * The description information for the Identity Center (SSO) Application
     */
    description?: pulumi.Input<string>;
    /**
     * The ARN of the instance of IAM Identity Center under which the operation will run
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name you want to assign to this Identity Center (SSO) Application
     */
    name?: pulumi.Input<string>;
    /**
     * A structure that describes the options for the portal associated with an application
     */
    portalOptions?: pulumi.Input<inputs.sso.ApplicationPortalOptionsConfigurationArgs>;
    /**
     * Specifies whether the application is enabled or disabled
     */
    status?: pulumi.Input<enums.sso.ApplicationStatus>;
    /**
     * Specifies tags to be attached to the application
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
