import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for StateMachineVersion
 */
export declare class StateMachineVersion extends pulumi.CustomResource {
    /**
     * Get an existing StateMachineVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StateMachineVersion;
    /**
     * Returns true if the given object is an instance of StateMachineVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StateMachineVersion;
    /**
     * Returns the ARN of the state machine version. For example, `arn:aws:states:us-east-1:123456789012:stateMachine:myStateMachine:1` .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * An optional description of the state machine version.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the state machine.
     */
    readonly stateMachineArn: pulumi.Output<string>;
    /**
     * Identifier for a state machine revision, which is an immutable, read-only snapshot of a state machine’s definition and configuration.
     *
     * Only publish the state machine version if the current state machine's revision ID matches the specified ID. Use this option to avoid publishing a version if the state machine has changed since you last updated it.
     *
     * To specify the initial state machine revision, set the value as `INITIAL` .
     */
    readonly stateMachineRevisionId: pulumi.Output<string | undefined>;
    /**
     * Create a StateMachineVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StateMachineVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StateMachineVersion resource.
 */
export interface StateMachineVersionArgs {
    /**
     * An optional description of the state machine version.
     */
    description?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the state machine.
     */
    stateMachineArn: pulumi.Input<string>;
    /**
     * Identifier for a state machine revision, which is an immutable, read-only snapshot of a state machine’s definition and configuration.
     *
     * Only publish the state machine version if the current state machine's revision ID matches the specified ID. Use this option to avoid publishing a version if the state machine has changed since you last updated it.
     *
     * To specify the initial state machine revision, set the value as `INITIAL` .
     */
    stateMachineRevisionId?: pulumi.Input<string>;
}
