import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::Timestream::InfluxDBInstance resource creates an InfluxDB instance.
 */
export declare function getInfluxDbInstance(args: GetInfluxDbInstanceArgs, opts?: pulumi.InvokeOptions): Promise<GetInfluxDbInstanceResult>;
export interface GetInfluxDbInstanceArgs {
    /**
     * The service generated unique identifier for InfluxDB instance.
     */
    id: string;
}
export interface GetInfluxDbInstanceResult {
    /**
     * The Amazon Resource Name (ARN) that is associated with the InfluxDB instance.
     */
    readonly arn?: string;
    /**
     * The Availability Zone (AZ) where the InfluxDB instance is created.
     */
    readonly availabilityZone?: string;
    /**
     * The compute instance of the InfluxDB instance.
     */
    readonly dbInstanceType?: enums.timestream.InfluxDbInstanceDbInstanceType;
    /**
     * The name of an existing InfluxDB parameter group.
     */
    readonly dbParameterGroupIdentifier?: string;
    /**
     * Deployment type of the InfluxDB Instance.
     */
    readonly deploymentType?: enums.timestream.InfluxDbInstanceDeploymentType;
    /**
     * The connection endpoint for the InfluxDB instance.
     */
    readonly endpoint?: string;
    /**
     * The service generated unique identifier for InfluxDB instance.
     */
    readonly id?: string;
    /**
     * The Auth parameters secret Amazon Resource name (ARN) that is associated with the InfluxDB instance.
     */
    readonly influxAuthParametersSecretArn?: string;
    /**
     * Configuration for sending logs to customer account from the InfluxDB instance.
     */
    readonly logDeliveryConfiguration?: outputs.timestream.LogDeliveryConfigurationProperties;
    /**
     * The port number on which InfluxDB accepts connections.
     */
    readonly port?: number;
    /**
     * The Secondary Availability Zone (AZ) where the InfluxDB instance is created, if DeploymentType is set as WITH_MULTIAZ_STANDBY.
     */
    readonly secondaryAvailabilityZone?: string;
    /**
     * Status of the InfluxDB Instance.
     */
    readonly status?: enums.timestream.InfluxDbInstanceStatus;
    /**
     * An arbitrary set of tags (key-value pairs) for this DB instance.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::Timestream::InfluxDBInstance resource creates an InfluxDB instance.
 */
export declare function getInfluxDbInstanceOutput(args: GetInfluxDbInstanceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInfluxDbInstanceResult>;
export interface GetInfluxDbInstanceOutputArgs {
    /**
     * The service generated unique identifier for InfluxDB instance.
     */
    id: pulumi.Input<string>;
}
