import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::Wisdom::AIPromptVersion Resource Type
 */
export declare function getAiPromptVersion(args: GetAiPromptVersionArgs, opts?: pulumi.InvokeOptions): Promise<GetAiPromptVersionResult>;
export interface GetAiPromptVersionArgs {
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    aiPromptId: string;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: string;
    /**
     * The version number for this AI Prompt version.
     */
    versionNumber: number;
}
export interface GetAiPromptVersionResult {
    /**
     * The ARN of the AI prompt.
     */
    readonly aiPromptArn?: string;
    readonly aiPromptVersionId?: string;
    readonly assistantArn?: string;
    /**
     * The version number for this AI Prompt version.
     */
    readonly versionNumber?: number;
}
/**
 * Definition of AWS::Wisdom::AIPromptVersion Resource Type
 */
export declare function getAiPromptVersionOutput(args: GetAiPromptVersionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAiPromptVersionResult>;
export interface GetAiPromptVersionOutputArgs {
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    aiPromptId: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: pulumi.Input<string>;
    /**
     * The version number for this AI Prompt version.
     */
    versionNumber: pulumi.Input<number>;
}
