import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::WorkSpacesWeb::UserSettings Resource Type
 */
export declare function getUserSettings(args: GetUserSettingsArgs, opts?: pulumi.InvokeOptions): Promise<GetUserSettingsResult>;
export interface GetUserSettingsArgs {
    /**
     * The ARN of the user settings.
     */
    userSettingsArn: string;
}
export interface GetUserSettingsResult {
    /**
     * The additional encryption context of the user settings.
     */
    readonly additionalEncryptionContext?: {
        [key: string]: string;
    };
    /**
     * A list of web portal ARNs that this user settings resource is associated with.
     */
    readonly associatedPortalArns?: string[];
    /**
     * The configuration that specifies which cookies should be synchronized from the end user's local browser to the remote browser.
     */
    readonly cookieSynchronizationConfiguration?: outputs.workspacesweb.UserSettingsCookieSynchronizationConfiguration;
    /**
     * Specifies whether the user can copy text from the streaming session to the local device.
     */
    readonly copyAllowed?: enums.workspacesweb.UserSettingsEnabledType;
    /**
     * The customer managed key used to encrypt sensitive information in the user settings.
     */
    readonly customerManagedKey?: string;
    /**
     * Specifies whether the user can use deep links that open automatically when connecting to a session.
     */
    readonly deepLinkAllowed?: enums.workspacesweb.UserSettingsEnabledType;
    /**
     * The amount of time that a streaming session remains active after users disconnect.
     */
    readonly disconnectTimeoutInMinutes?: number;
    /**
     * Specifies whether the user can download files from the streaming session to the local device.
     */
    readonly downloadAllowed?: enums.workspacesweb.UserSettingsEnabledType;
    /**
     * The amount of time that users can be idle (inactive) before they are disconnected from their streaming session and the disconnect timeout interval begins.
     */
    readonly idleDisconnectTimeoutInMinutes?: number;
    /**
     * Specifies whether the user can paste text from the local device to the streaming session.
     */
    readonly pasteAllowed?: enums.workspacesweb.UserSettingsEnabledType;
    /**
     * Specifies whether the user can print to the local device.
     */
    readonly printAllowed?: enums.workspacesweb.UserSettingsEnabledType;
    /**
     * The tags to add to the user settings resource. A tag is a key-value pair.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The configuration of the toolbar. This allows administrators to select the toolbar type and visual mode, set maximum display resolution for sessions, and choose which items are visible to end users during their sessions. If administrators do not modify these settings, end users retain control over their toolbar preferences.
     */
    readonly toolbarConfiguration?: outputs.workspacesweb.UserSettingsToolbarConfiguration;
    /**
     * Specifies whether the user can upload files from the local device to the streaming session.
     */
    readonly uploadAllowed?: enums.workspacesweb.UserSettingsEnabledType;
    /**
     * The ARN of the user settings.
     */
    readonly userSettingsArn?: string;
}
/**
 * Definition of AWS::WorkSpacesWeb::UserSettings Resource Type
 */
export declare function getUserSettingsOutput(args: GetUserSettingsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserSettingsResult>;
export interface GetUserSettingsOutputArgs {
    /**
     * The ARN of the user settings.
     */
    userSettingsArn: pulumi.Input<string>;
}
